# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .deploy_artifact_source import DeployArtifactSource
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenericDeployArtifactSource(DeployArtifactSource):
    """
    Specifies the Artifact Registry source details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GenericDeployArtifactSource object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.GenericDeployArtifactSource.deploy_artifact_source_type` attribute
        of this class is ``GENERIC_ARTIFACT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param deploy_artifact_source_type:
            The value to assign to the deploy_artifact_source_type property of this GenericDeployArtifactSource.
            Allowed values for this property are: "INLINE", "OCIR", "GENERIC_ARTIFACT"
        :type deploy_artifact_source_type: str

        :param repository_id:
            The value to assign to the repository_id property of this GenericDeployArtifactSource.
        :type repository_id: str

        :param deploy_artifact_path:
            The value to assign to the deploy_artifact_path property of this GenericDeployArtifactSource.
        :type deploy_artifact_path: str

        :param deploy_artifact_version:
            The value to assign to the deploy_artifact_version property of this GenericDeployArtifactSource.
        :type deploy_artifact_version: str

        """
        self.swagger_types = {
            'deploy_artifact_source_type': 'str',
            'repository_id': 'str',
            'deploy_artifact_path': 'str',
            'deploy_artifact_version': 'str'
        }

        self.attribute_map = {
            'deploy_artifact_source_type': 'deployArtifactSourceType',
            'repository_id': 'repositoryId',
            'deploy_artifact_path': 'deployArtifactPath',
            'deploy_artifact_version': 'deployArtifactVersion'
        }

        self._deploy_artifact_source_type = None
        self._repository_id = None
        self._deploy_artifact_path = None
        self._deploy_artifact_version = None
        self._deploy_artifact_source_type = 'GENERIC_ARTIFACT'

    @property
    def repository_id(self):
        """
        **[Required]** Gets the repository_id of this GenericDeployArtifactSource.
        The OCID of a repository


        :return: The repository_id of this GenericDeployArtifactSource.
        :rtype: str
        """
        return self._repository_id

    @repository_id.setter
    def repository_id(self, repository_id):
        """
        Sets the repository_id of this GenericDeployArtifactSource.
        The OCID of a repository


        :param repository_id: The repository_id of this GenericDeployArtifactSource.
        :type: str
        """
        self._repository_id = repository_id

    @property
    def deploy_artifact_path(self):
        """
        **[Required]** Gets the deploy_artifact_path of this GenericDeployArtifactSource.
        Specifies the artifact path in the repository.


        :return: The deploy_artifact_path of this GenericDeployArtifactSource.
        :rtype: str
        """
        return self._deploy_artifact_path

    @deploy_artifact_path.setter
    def deploy_artifact_path(self, deploy_artifact_path):
        """
        Sets the deploy_artifact_path of this GenericDeployArtifactSource.
        Specifies the artifact path in the repository.


        :param deploy_artifact_path: The deploy_artifact_path of this GenericDeployArtifactSource.
        :type: str
        """
        self._deploy_artifact_path = deploy_artifact_path

    @property
    def deploy_artifact_version(self):
        """
        **[Required]** Gets the deploy_artifact_version of this GenericDeployArtifactSource.
        Users can set this as a placeholder value that refers to a pipeline parameter, for example, ${appVersion}.


        :return: The deploy_artifact_version of this GenericDeployArtifactSource.
        :rtype: str
        """
        return self._deploy_artifact_version

    @deploy_artifact_version.setter
    def deploy_artifact_version(self, deploy_artifact_version):
        """
        Sets the deploy_artifact_version of this GenericDeployArtifactSource.
        Users can set this as a placeholder value that refers to a pipeline parameter, for example, ${appVersion}.


        :param deploy_artifact_version: The deploy_artifact_version of this GenericDeployArtifactSource.
        :type: str
        """
        self._deploy_artifact_version = deploy_artifact_version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ServiceCategory(object):
    """
    Information about the incident classifier.
    """

    #: A constant which can be used with the scope property of a ServiceCategory.
    #: This constant has a value of "AD"
    SCOPE_AD = "AD"

    #: A constant which can be used with the scope property of a ServiceCategory.
    #: This constant has a value of "REGION"
    SCOPE_REGION = "REGION"

    #: A constant which can be used with the scope property of a ServiceCategory.
    #: This constant has a value of "TENANCY"
    SCOPE_TENANCY = "TENANCY"

    #: A constant which can be used with the scope property of a ServiceCategory.
    #: This constant has a value of "NONE"
    SCOPE_NONE = "NONE"

    #: A constant which can be used with the unit property of a ServiceCategory.
    #: This constant has a value of "COUNT"
    UNIT_COUNT = "COUNT"

    #: A constant which can be used with the unit property of a ServiceCategory.
    #: This constant has a value of "GB"
    UNIT_GB = "GB"

    #: A constant which can be used with the unit property of a ServiceCategory.
    #: This constant has a value of "NONE"
    UNIT_NONE = "NONE"

    def __init__(self, **kwargs):
        """
        Initializes a new ServiceCategory object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this ServiceCategory.
        :type key: str

        :param name:
            The value to assign to the name property of this ServiceCategory.
        :type name: str

        :param label:
            The value to assign to the label property of this ServiceCategory.
        :type label: str

        :param description:
            The value to assign to the description property of this ServiceCategory.
        :type description: str

        :param issue_type_list:
            The value to assign to the issue_type_list property of this ServiceCategory.
        :type issue_type_list: list[oci.cims.models.IssueType]

        :param scope:
            The value to assign to the scope property of this ServiceCategory.
            Allowed values for this property are: "AD", "REGION", "TENANCY", "NONE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type scope: str

        :param unit:
            The value to assign to the unit property of this ServiceCategory.
            Allowed values for this property are: "COUNT", "GB", "NONE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type unit: str

        :param limit_id:
            The value to assign to the limit_id property of this ServiceCategory.
        :type limit_id: str

        """
        self.swagger_types = {
            'key': 'str',
            'name': 'str',
            'label': 'str',
            'description': 'str',
            'issue_type_list': 'list[IssueType]',
            'scope': 'str',
            'unit': 'str',
            'limit_id': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'name': 'name',
            'label': 'label',
            'description': 'description',
            'issue_type_list': 'issueTypeList',
            'scope': 'scope',
            'unit': 'unit',
            'limit_id': 'limitId'
        }

        self._key = None
        self._name = None
        self._label = None
        self._description = None
        self._issue_type_list = None
        self._scope = None
        self._unit = None
        self._limit_id = None

    @property
    def key(self):
        """
        Gets the key of this ServiceCategory.
        The unique ID that identifies a classifier.


        :return: The key of this ServiceCategory.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ServiceCategory.
        The unique ID that identifies a classifier.


        :param key: The key of this ServiceCategory.
        :type: str
        """
        self._key = key

    @property
    def name(self):
        """
        Gets the name of this ServiceCategory.
        The name of the classifier.


        :return: The name of this ServiceCategory.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ServiceCategory.
        The name of the classifier.


        :param name: The name of this ServiceCategory.
        :type: str
        """
        self._name = name

    @property
    def label(self):
        """
        Gets the label of this ServiceCategory.
        The label for the classifier.


        :return: The label of this ServiceCategory.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this ServiceCategory.
        The label for the classifier.


        :param label: The label of this ServiceCategory.
        :type: str
        """
        self._label = label

    @property
    def description(self):
        """
        Gets the description of this ServiceCategory.
        The text describing the classifier.


        :return: The description of this ServiceCategory.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ServiceCategory.
        The text describing the classifier.


        :param description: The description of this ServiceCategory.
        :type: str
        """
        self._description = description

    @property
    def issue_type_list(self):
        """
        Gets the issue_type_list of this ServiceCategory.
        The list of issues.


        :return: The issue_type_list of this ServiceCategory.
        :rtype: list[oci.cims.models.IssueType]
        """
        return self._issue_type_list

    @issue_type_list.setter
    def issue_type_list(self, issue_type_list):
        """
        Sets the issue_type_list of this ServiceCategory.
        The list of issues.


        :param issue_type_list: The issue_type_list of this ServiceCategory.
        :type: list[oci.cims.models.IssueType]
        """
        self._issue_type_list = issue_type_list

    @property
    def scope(self):
        """
        Gets the scope of this ServiceCategory.
        The scope of the incident.

        Allowed values for this property are: "AD", "REGION", "TENANCY", "NONE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The scope of this ServiceCategory.
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this ServiceCategory.
        The scope of the incident.


        :param scope: The scope of this ServiceCategory.
        :type: str
        """
        allowed_values = ["AD", "REGION", "TENANCY", "NONE"]
        if not value_allowed_none_or_none_sentinel(scope, allowed_values):
            scope = 'UNKNOWN_ENUM_VALUE'
        self._scope = scope

    @property
    def unit(self):
        """
        Gets the unit of this ServiceCategory.
        The unit to use to measure the service category or resource.

        Allowed values for this property are: "COUNT", "GB", "NONE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The unit of this ServiceCategory.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this ServiceCategory.
        The unit to use to measure the service category or resource.


        :param unit: The unit of this ServiceCategory.
        :type: str
        """
        allowed_values = ["COUNT", "GB", "NONE"]
        if not value_allowed_none_or_none_sentinel(unit, allowed_values):
            unit = 'UNKNOWN_ENUM_VALUE'
        self._unit = unit

    @property
    def limit_id(self):
        """
        Gets the limit_id of this ServiceCategory.
        The unique ID for the limit.


        :return: The limit_id of this ServiceCategory.
        :rtype: str
        """
        return self._limit_id

    @limit_id.setter
    def limit_id(self, limit_id):
        """
        Sets the limit_id of this ServiceCategory.
        The unique ID for the limit.


        :param limit_id: The limit_id of this ServiceCategory.
        :type: str
        """
        self._limit_id = limit_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .deploy_artifact_source import DeployArtifactSource
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InlineDeployArtifactSource(DeployArtifactSource):
    """
    Specifies the inline deployment artifact source details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InlineDeployArtifactSource object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.InlineDeployArtifactSource.deploy_artifact_source_type` attribute
        of this class is ``INLINE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param deploy_artifact_source_type:
            The value to assign to the deploy_artifact_source_type property of this InlineDeployArtifactSource.
            Allowed values for this property are: "INLINE", "OCIR", "GENERIC_ARTIFACT"
        :type deploy_artifact_source_type: str

        :param base64_encoded_content:
            The value to assign to the base64_encoded_content property of this InlineDeployArtifactSource.
        :type base64_encoded_content: str

        """
        self.swagger_types = {
            'deploy_artifact_source_type': 'str',
            'base64_encoded_content': 'str'
        }

        self.attribute_map = {
            'deploy_artifact_source_type': 'deployArtifactSourceType',
            'base64_encoded_content': 'base64EncodedContent'
        }

        self._deploy_artifact_source_type = None
        self._base64_encoded_content = None
        self._deploy_artifact_source_type = 'INLINE'

    @property
    def base64_encoded_content(self):
        """
        **[Required]** Gets the base64_encoded_content of this InlineDeployArtifactSource.
        base64 Encoded String


        :return: The base64_encoded_content of this InlineDeployArtifactSource.
        :rtype: str
        """
        return self._base64_encoded_content

    @base64_encoded_content.setter
    def base64_encoded_content(self, base64_encoded_content):
        """
        Sets the base64_encoded_content of this InlineDeployArtifactSource.
        base64 Encoded String


        :param base64_encoded_content: The base64_encoded_content of this InlineDeployArtifactSource.
        :type: str
        """
        self._base64_encoded_content = base64_encoded_content

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Recurrence(object):
    """
    An object for representing a recurrence time interval
    """

    #: A constant which can be used with the interval_type property of a Recurrence.
    #: This constant has a value of "MINUTES"
    INTERVAL_TYPE_MINUTES = "MINUTES"

    #: A constant which can be used with the interval_type property of a Recurrence.
    #: This constant has a value of "HOURS"
    INTERVAL_TYPE_HOURS = "HOURS"

    #: A constant which can be used with the interval_type property of a Recurrence.
    #: This constant has a value of "DAYS"
    INTERVAL_TYPE_DAYS = "DAYS"

    #: A constant which can be used with the interval_type property of a Recurrence.
    #: This constant has a value of "WEEKS"
    INTERVAL_TYPE_WEEKS = "WEEKS"

    def __init__(self, **kwargs):
        """
        Initializes a new Recurrence object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param interval_type:
            The value to assign to the interval_type property of this Recurrence.
            Allowed values for this property are: "MINUTES", "HOURS", "DAYS", "WEEKS"
        :type interval_type: str

        :param interval_value:
            The value to assign to the interval_value property of this Recurrence.
        :type interval_value: str

        """
        self.swagger_types = {
            'interval_type': 'str',
            'interval_value': 'str'
        }

        self.attribute_map = {
            'interval_type': 'intervalType',
            'interval_value': 'intervalValue'
        }

        self._interval_type = None
        self._interval_value = None

    @property
    def interval_type(self):
        """
        **[Required]** Gets the interval_type of this Recurrence.
        the interval period for the recurrence

        Allowed values for this property are: "MINUTES", "HOURS", "DAYS", "WEEKS"


        :return: The interval_type of this Recurrence.
        :rtype: str
        """
        return self._interval_type

    @interval_type.setter
    def interval_type(self, interval_type):
        """
        Sets the interval_type of this Recurrence.
        the interval period for the recurrence


        :param interval_type: The interval_type of this Recurrence.
        :type: str
        """
        allowed_values = ["MINUTES", "HOURS", "DAYS", "WEEKS"]
        if not value_allowed_none_or_none_sentinel(interval_type, allowed_values):
            raise ValueError(
                "Invalid value for `interval_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._interval_type = interval_type

    @property
    def interval_value(self):
        """
        **[Required]** Gets the interval_value of this Recurrence.
        the value for the interval period for the recurrence


        :return: The interval_value of this Recurrence.
        :rtype: str
        """
        return self._interval_value

    @interval_value.setter
    def interval_value(self, interval_value):
        """
        Sets the interval_value of this Recurrence.
        the value for the interval period for the recurrence


        :param interval_value: The interval_value of this Recurrence.
        :type: str
        """
        self._interval_value = interval_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Patch(object):
    """
    The patch object contains the audit summary information and the definition of the patch.
    """

    #: A constant which can be used with the patch_type property of a Patch.
    #: This constant has a value of "PUBLISH"
    PATCH_TYPE_PUBLISH = "PUBLISH"

    #: A constant which can be used with the patch_type property of a Patch.
    #: This constant has a value of "REFRESH"
    PATCH_TYPE_REFRESH = "REFRESH"

    #: A constant which can be used with the patch_type property of a Patch.
    #: This constant has a value of "UNPUBLISH"
    PATCH_TYPE_UNPUBLISH = "UNPUBLISH"

    #: A constant which can be used with the patch_status property of a Patch.
    #: This constant has a value of "QUEUED"
    PATCH_STATUS_QUEUED = "QUEUED"

    #: A constant which can be used with the patch_status property of a Patch.
    #: This constant has a value of "SUCCESSFUL"
    PATCH_STATUS_SUCCESSFUL = "SUCCESSFUL"

    #: A constant which can be used with the patch_status property of a Patch.
    #: This constant has a value of "FAILED"
    PATCH_STATUS_FAILED = "FAILED"

    #: A constant which can be used with the patch_status property of a Patch.
    #: This constant has a value of "IN_PROGRESS"
    PATCH_STATUS_IN_PROGRESS = "IN_PROGRESS"

    def __init__(self, **kwargs):
        """
        Initializes a new Patch object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this Patch.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this Patch.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this Patch.
        :type model_version: str

        :param name:
            The value to assign to the name property of this Patch.
        :type name: str

        :param description:
            The value to assign to the description property of this Patch.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this Patch.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this Patch.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this Patch.
        :type identifier: str

        :param time_patched:
            The value to assign to the time_patched property of this Patch.
        :type time_patched: datetime

        :param error_messages:
            The value to assign to the error_messages property of this Patch.
        :type error_messages: dict(str, str)

        :param application_version:
            The value to assign to the application_version property of this Patch.
        :type application_version: int

        :param patch_type:
            The value to assign to the patch_type property of this Patch.
            Allowed values for this property are: "PUBLISH", "REFRESH", "UNPUBLISH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type patch_type: str

        :param patch_status:
            The value to assign to the patch_status property of this Patch.
            Allowed values for this property are: "QUEUED", "SUCCESSFUL", "FAILED", "IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type patch_status: str

        :param dependent_object_metadata:
            The value to assign to the dependent_object_metadata property of this Patch.
        :type dependent_object_metadata: list[oci.data_integration.models.PatchObjectMetadata]

        :param patch_object_metadata:
            The value to assign to the patch_object_metadata property of this Patch.
        :type patch_object_metadata: list[oci.data_integration.models.PatchObjectMetadata]

        :param parent_ref:
            The value to assign to the parent_ref property of this Patch.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param metadata:
            The value to assign to the metadata property of this Patch.
        :type metadata: oci.data_integration.models.ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this Patch.
        :type key_map: dict(str, str)

        """
        self.swagger_types = {
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'time_patched': 'datetime',
            'error_messages': 'dict(str, str)',
            'application_version': 'int',
            'patch_type': 'str',
            'patch_status': 'str',
            'dependent_object_metadata': 'list[PatchObjectMetadata]',
            'patch_object_metadata': 'list[PatchObjectMetadata]',
            'parent_ref': 'ParentReference',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)'
        }

        self.attribute_map = {
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'time_patched': 'timePatched',
            'error_messages': 'errorMessages',
            'application_version': 'applicationVersion',
            'patch_type': 'patchType',
            'patch_status': 'patchStatus',
            'dependent_object_metadata': 'dependentObjectMetadata',
            'patch_object_metadata': 'patchObjectMetadata',
            'parent_ref': 'parentRef',
            'metadata': 'metadata',
            'key_map': 'keyMap'
        }

        self._key = None
        self._model_type = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._time_patched = None
        self._error_messages = None
        self._application_version = None
        self._patch_type = None
        self._patch_status = None
        self._dependent_object_metadata = None
        self._patch_object_metadata = None
        self._parent_ref = None
        self._metadata = None
        self._key_map = None

    @property
    def key(self):
        """
        Gets the key of this Patch.
        The object key.


        :return: The key of this Patch.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Patch.
        The object key.


        :param key: The key of this Patch.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this Patch.
        The object type.


        :return: The model_type of this Patch.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this Patch.
        The object type.


        :param model_type: The model_type of this Patch.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this Patch.
        The object's model version.


        :return: The model_version of this Patch.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this Patch.
        The object's model version.


        :param model_version: The model_version of this Patch.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        Gets the name of this Patch.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this Patch.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Patch.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this Patch.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Patch.
        Detailed description for the object.


        :return: The description of this Patch.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Patch.
        Detailed description for the object.


        :param description: The description of this Patch.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this Patch.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this Patch.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this Patch.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this Patch.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this Patch.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this Patch.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this Patch.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this Patch.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this Patch.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this Patch.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this Patch.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this Patch.
        :type: str
        """
        self._identifier = identifier

    @property
    def time_patched(self):
        """
        Gets the time_patched of this Patch.
        The date and time the patch was applied, in the timestamp format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_patched of this Patch.
        :rtype: datetime
        """
        return self._time_patched

    @time_patched.setter
    def time_patched(self, time_patched):
        """
        Sets the time_patched of this Patch.
        The date and time the patch was applied, in the timestamp format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_patched: The time_patched of this Patch.
        :type: datetime
        """
        self._time_patched = time_patched

    @property
    def error_messages(self):
        """
        Gets the error_messages of this Patch.
        The errors encountered while applying the patch, if any.


        :return: The error_messages of this Patch.
        :rtype: dict(str, str)
        """
        return self._error_messages

    @error_messages.setter
    def error_messages(self, error_messages):
        """
        Sets the error_messages of this Patch.
        The errors encountered while applying the patch, if any.


        :param error_messages: The error_messages of this Patch.
        :type: dict(str, str)
        """
        self._error_messages = error_messages

    @property
    def application_version(self):
        """
        Gets the application_version of this Patch.
        The application version of the patch.


        :return: The application_version of this Patch.
        :rtype: int
        """
        return self._application_version

    @application_version.setter
    def application_version(self, application_version):
        """
        Sets the application_version of this Patch.
        The application version of the patch.


        :param application_version: The application_version of this Patch.
        :type: int
        """
        self._application_version = application_version

    @property
    def patch_type(self):
        """
        Gets the patch_type of this Patch.
        The type of the patch applied or being applied on the application.

        Allowed values for this property are: "PUBLISH", "REFRESH", "UNPUBLISH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The patch_type of this Patch.
        :rtype: str
        """
        return self._patch_type

    @patch_type.setter
    def patch_type(self, patch_type):
        """
        Sets the patch_type of this Patch.
        The type of the patch applied or being applied on the application.


        :param patch_type: The patch_type of this Patch.
        :type: str
        """
        allowed_values = ["PUBLISH", "REFRESH", "UNPUBLISH"]
        if not value_allowed_none_or_none_sentinel(patch_type, allowed_values):
            patch_type = 'UNKNOWN_ENUM_VALUE'
        self._patch_type = patch_type

    @property
    def patch_status(self):
        """
        Gets the patch_status of this Patch.
        Status of the patch applied or being applied on the application

        Allowed values for this property are: "QUEUED", "SUCCESSFUL", "FAILED", "IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The patch_status of this Patch.
        :rtype: str
        """
        return self._patch_status

    @patch_status.setter
    def patch_status(self, patch_status):
        """
        Sets the patch_status of this Patch.
        Status of the patch applied or being applied on the application


        :param patch_status: The patch_status of this Patch.
        :type: str
        """
        allowed_values = ["QUEUED", "SUCCESSFUL", "FAILED", "IN_PROGRESS"]
        if not value_allowed_none_or_none_sentinel(patch_status, allowed_values):
            patch_status = 'UNKNOWN_ENUM_VALUE'
        self._patch_status = patch_status

    @property
    def dependent_object_metadata(self):
        """
        Gets the dependent_object_metadata of this Patch.
        List of dependent objects in this patch.


        :return: The dependent_object_metadata of this Patch.
        :rtype: list[oci.data_integration.models.PatchObjectMetadata]
        """
        return self._dependent_object_metadata

    @dependent_object_metadata.setter
    def dependent_object_metadata(self, dependent_object_metadata):
        """
        Sets the dependent_object_metadata of this Patch.
        List of dependent objects in this patch.


        :param dependent_object_metadata: The dependent_object_metadata of this Patch.
        :type: list[oci.data_integration.models.PatchObjectMetadata]
        """
        self._dependent_object_metadata = dependent_object_metadata

    @property
    def patch_object_metadata(self):
        """
        Gets the patch_object_metadata of this Patch.
        List of objects that are published or unpublished in this patch.


        :return: The patch_object_metadata of this Patch.
        :rtype: list[oci.data_integration.models.PatchObjectMetadata]
        """
        return self._patch_object_metadata

    @patch_object_metadata.setter
    def patch_object_metadata(self, patch_object_metadata):
        """
        Sets the patch_object_metadata of this Patch.
        List of objects that are published or unpublished in this patch.


        :param patch_object_metadata: The patch_object_metadata of this Patch.
        :type: list[oci.data_integration.models.PatchObjectMetadata]
        """
        self._patch_object_metadata = patch_object_metadata

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this Patch.

        :return: The parent_ref of this Patch.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this Patch.

        :param parent_ref: The parent_ref of this Patch.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def metadata(self):
        """
        Gets the metadata of this Patch.

        :return: The metadata of this Patch.
        :rtype: oci.data_integration.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this Patch.

        :param metadata: The metadata of this Patch.
        :type: oci.data_integration.models.ObjectMetadata
        """
        self._metadata = metadata

    @property
    def key_map(self):
        """
        Gets the key_map of this Patch.
        A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.


        :return: The key_map of this Patch.
        :rtype: dict(str, str)
        """
        return self._key_map

    @key_map.setter
    def key_map(self, key_map):
        """
        Sets the key_map of this Patch.
        A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.


        :param key_map: The key_map of this Patch.
        :type: dict(str, str)
        """
        self._key_map = key_map

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateEsxiHostDetails(object):
    """
    Details of the ESXi host to add to the SDDC.
    """

    #: A constant which can be used with the current_sku property of a CreateEsxiHostDetails.
    #: This constant has a value of "HOUR"
    CURRENT_SKU_HOUR = "HOUR"

    #: A constant which can be used with the current_sku property of a CreateEsxiHostDetails.
    #: This constant has a value of "MONTH"
    CURRENT_SKU_MONTH = "MONTH"

    #: A constant which can be used with the current_sku property of a CreateEsxiHostDetails.
    #: This constant has a value of "ONE_YEAR"
    CURRENT_SKU_ONE_YEAR = "ONE_YEAR"

    #: A constant which can be used with the current_sku property of a CreateEsxiHostDetails.
    #: This constant has a value of "THREE_YEARS"
    CURRENT_SKU_THREE_YEARS = "THREE_YEARS"

    #: A constant which can be used with the next_sku property of a CreateEsxiHostDetails.
    #: This constant has a value of "HOUR"
    NEXT_SKU_HOUR = "HOUR"

    #: A constant which can be used with the next_sku property of a CreateEsxiHostDetails.
    #: This constant has a value of "MONTH"
    NEXT_SKU_MONTH = "MONTH"

    #: A constant which can be used with the next_sku property of a CreateEsxiHostDetails.
    #: This constant has a value of "ONE_YEAR"
    NEXT_SKU_ONE_YEAR = "ONE_YEAR"

    #: A constant which can be used with the next_sku property of a CreateEsxiHostDetails.
    #: This constant has a value of "THREE_YEARS"
    NEXT_SKU_THREE_YEARS = "THREE_YEARS"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateEsxiHostDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param sddc_id:
            The value to assign to the sddc_id property of this CreateEsxiHostDetails.
        :type sddc_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateEsxiHostDetails.
        :type display_name: str

        :param current_sku:
            The value to assign to the current_sku property of this CreateEsxiHostDetails.
            Allowed values for this property are: "HOUR", "MONTH", "ONE_YEAR", "THREE_YEARS"
        :type current_sku: str

        :param next_sku:
            The value to assign to the next_sku property of this CreateEsxiHostDetails.
            Allowed values for this property are: "HOUR", "MONTH", "ONE_YEAR", "THREE_YEARS"
        :type next_sku: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateEsxiHostDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateEsxiHostDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'sddc_id': 'str',
            'display_name': 'str',
            'current_sku': 'str',
            'next_sku': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'sddc_id': 'sddcId',
            'display_name': 'displayName',
            'current_sku': 'currentSku',
            'next_sku': 'nextSku',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._sddc_id = None
        self._display_name = None
        self._current_sku = None
        self._next_sku = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def sddc_id(self):
        """
        **[Required]** Gets the sddc_id of this CreateEsxiHostDetails.
        The `OCID`__ of the SDDC to add the
        ESXi host to.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The sddc_id of this CreateEsxiHostDetails.
        :rtype: str
        """
        return self._sddc_id

    @sddc_id.setter
    def sddc_id(self, sddc_id):
        """
        Sets the sddc_id of this CreateEsxiHostDetails.
        The `OCID`__ of the SDDC to add the
        ESXi host to.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param sddc_id: The sddc_id of this CreateEsxiHostDetails.
        :type: str
        """
        self._sddc_id = sddc_id

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateEsxiHostDetails.
        A descriptive name for the ESXi host. It's changeable.
        Esxi Host name requirements are 1-16 character length limit, Must start with a letter, Must be English letters, numbers, - only, No repeating hyphens, Must be unique within the SDDC.

        If this attribute is not specified, the SDDC's `instanceDisplayNamePrefix` attribute is used
        to name and incrementally number the ESXi host. For example, if you're creating the fourth
        ESXi host in the SDDC, and `instanceDisplayNamePrefix` is `MySDDC`, the host's display
        name is `MySDDC-4`.

        Avoid entering confidential information.


        :return: The display_name of this CreateEsxiHostDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateEsxiHostDetails.
        A descriptive name for the ESXi host. It's changeable.
        Esxi Host name requirements are 1-16 character length limit, Must start with a letter, Must be English letters, numbers, - only, No repeating hyphens, Must be unique within the SDDC.

        If this attribute is not specified, the SDDC's `instanceDisplayNamePrefix` attribute is used
        to name and incrementally number the ESXi host. For example, if you're creating the fourth
        ESXi host in the SDDC, and `instanceDisplayNamePrefix` is `MySDDC`, the host's display
        name is `MySDDC-4`.

        Avoid entering confidential information.


        :param display_name: The display_name of this CreateEsxiHostDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def current_sku(self):
        """
        Gets the current_sku of this CreateEsxiHostDetails.
        Billing option selected during SDDC creation.
        Oracle Cloud Infrastructure VMware Solution supports the following billing interval SKUs:
        HOUR, MONTH, ONE_YEAR, and THREE_YEARS.
        :func:`list_supported_skus`.

        Allowed values for this property are: "HOUR", "MONTH", "ONE_YEAR", "THREE_YEARS"


        :return: The current_sku of this CreateEsxiHostDetails.
        :rtype: str
        """
        return self._current_sku

    @current_sku.setter
    def current_sku(self, current_sku):
        """
        Sets the current_sku of this CreateEsxiHostDetails.
        Billing option selected during SDDC creation.
        Oracle Cloud Infrastructure VMware Solution supports the following billing interval SKUs:
        HOUR, MONTH, ONE_YEAR, and THREE_YEARS.
        :func:`list_supported_skus`.


        :param current_sku: The current_sku of this CreateEsxiHostDetails.
        :type: str
        """
        allowed_values = ["HOUR", "MONTH", "ONE_YEAR", "THREE_YEARS"]
        if not value_allowed_none_or_none_sentinel(current_sku, allowed_values):
            raise ValueError(
                "Invalid value for `current_sku`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._current_sku = current_sku

    @property
    def next_sku(self):
        """
        Gets the next_sku of this CreateEsxiHostDetails.
        Billing option to switch to once existing billing cycle ends.
        If nextSku is null or empty, currentSku will be used to continue with next billing term.
        :func:`list_supported_skus`.

        Allowed values for this property are: "HOUR", "MONTH", "ONE_YEAR", "THREE_YEARS"


        :return: The next_sku of this CreateEsxiHostDetails.
        :rtype: str
        """
        return self._next_sku

    @next_sku.setter
    def next_sku(self, next_sku):
        """
        Sets the next_sku of this CreateEsxiHostDetails.
        Billing option to switch to once existing billing cycle ends.
        If nextSku is null or empty, currentSku will be used to continue with next billing term.
        :func:`list_supported_skus`.


        :param next_sku: The next_sku of this CreateEsxiHostDetails.
        :type: str
        """
        allowed_values = ["HOUR", "MONTH", "ONE_YEAR", "THREE_YEARS"]
        if not value_allowed_none_or_none_sentinel(next_sku, allowed_values):
            raise ValueError(
                "Invalid value for `next_sku`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._next_sku = next_sku

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateEsxiHostDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateEsxiHostDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateEsxiHostDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateEsxiHostDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateEsxiHostDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateEsxiHostDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateEsxiHostDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateEsxiHostDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputeCapacityReservation(object):
    """
    A template that defines the settings to use when creating compute capacity reservations.
    """

    #: A constant which can be used with the lifecycle_state property of a ComputeCapacityReservation.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ComputeCapacityReservation.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ComputeCapacityReservation.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ComputeCapacityReservation.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    #: A constant which can be used with the lifecycle_state property of a ComputeCapacityReservation.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ComputeCapacityReservation.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    def __init__(self, **kwargs):
        """
        Initializes a new ComputeCapacityReservation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this ComputeCapacityReservation.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ComputeCapacityReservation.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this ComputeCapacityReservation.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this ComputeCapacityReservation.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ComputeCapacityReservation.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this ComputeCapacityReservation.
        :type id: str

        :param is_default_reservation:
            The value to assign to the is_default_reservation property of this ComputeCapacityReservation.
        :type is_default_reservation: bool

        :param instance_reservation_configs:
            The value to assign to the instance_reservation_configs property of this ComputeCapacityReservation.
        :type instance_reservation_configs: list[oci.core.models.InstanceReservationConfig]

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ComputeCapacityReservation.
            Allowed values for this property are: "ACTIVE", "CREATING", "UPDATING", "MOVING", "DELETED", "DELETING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param reserved_instance_count:
            The value to assign to the reserved_instance_count property of this ComputeCapacityReservation.
        :type reserved_instance_count: int

        :param time_updated:
            The value to assign to the time_updated property of this ComputeCapacityReservation.
        :type time_updated: datetime

        :param time_created:
            The value to assign to the time_created property of this ComputeCapacityReservation.
        :type time_created: datetime

        :param used_instance_count:
            The value to assign to the used_instance_count property of this ComputeCapacityReservation.
        :type used_instance_count: int

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'is_default_reservation': 'bool',
            'instance_reservation_configs': 'list[InstanceReservationConfig]',
            'lifecycle_state': 'str',
            'reserved_instance_count': 'int',
            'time_updated': 'datetime',
            'time_created': 'datetime',
            'used_instance_count': 'int'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'is_default_reservation': 'isDefaultReservation',
            'instance_reservation_configs': 'instanceReservationConfigs',
            'lifecycle_state': 'lifecycleState',
            'reserved_instance_count': 'reservedInstanceCount',
            'time_updated': 'timeUpdated',
            'time_created': 'timeCreated',
            'used_instance_count': 'usedInstanceCount'
        }

        self._availability_domain = None
        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._is_default_reservation = None
        self._instance_reservation_configs = None
        self._lifecycle_state = None
        self._reserved_instance_count = None
        self._time_updated = None
        self._time_created = None
        self._used_instance_count = None

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this ComputeCapacityReservation.
        The availability domain of the compute capacity reservation.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this ComputeCapacityReservation.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this ComputeCapacityReservation.
        The availability domain of the compute capacity reservation.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this ComputeCapacityReservation.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ComputeCapacityReservation.
        The `OCID`__ of the compartment
        containing the compute capacity reservation.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ComputeCapacityReservation.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ComputeCapacityReservation.
        The `OCID`__ of the compartment
        containing the compute capacity reservation.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ComputeCapacityReservation.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ComputeCapacityReservation.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ComputeCapacityReservation.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ComputeCapacityReservation.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ComputeCapacityReservation.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this ComputeCapacityReservation.
        A user-friendly name for the compute capacity reservation.
        It does not have to be unique, and it's changeable. Avoid entering confidential information.


        :return: The display_name of this ComputeCapacityReservation.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ComputeCapacityReservation.
        A user-friendly name for the compute capacity reservation.
        It does not have to be unique, and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this ComputeCapacityReservation.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ComputeCapacityReservation.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ComputeCapacityReservation.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ComputeCapacityReservation.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ComputeCapacityReservation.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ComputeCapacityReservation.
        The `OCID`__ of the compute capacity reservation.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this ComputeCapacityReservation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ComputeCapacityReservation.
        The `OCID`__ of the compute capacity reservation.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this ComputeCapacityReservation.
        :type: str
        """
        self._id = id

    @property
    def is_default_reservation(self):
        """
        Gets the is_default_reservation of this ComputeCapacityReservation.
        Whether this capacity reservation is the default.
        For more information, see `Capacity Reservations`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/reserve-capacity.htm#default


        :return: The is_default_reservation of this ComputeCapacityReservation.
        :rtype: bool
        """
        return self._is_default_reservation

    @is_default_reservation.setter
    def is_default_reservation(self, is_default_reservation):
        """
        Sets the is_default_reservation of this ComputeCapacityReservation.
        Whether this capacity reservation is the default.
        For more information, see `Capacity Reservations`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/reserve-capacity.htm#default


        :param is_default_reservation: The is_default_reservation of this ComputeCapacityReservation.
        :type: bool
        """
        self._is_default_reservation = is_default_reservation

    @property
    def instance_reservation_configs(self):
        """
        Gets the instance_reservation_configs of this ComputeCapacityReservation.
        The reservation configurations for the capacity reservation.

        To use the reservation for the desired shape, specify the shape, count, and
        optionally the fault domain where you want this configuration.


        :return: The instance_reservation_configs of this ComputeCapacityReservation.
        :rtype: list[oci.core.models.InstanceReservationConfig]
        """
        return self._instance_reservation_configs

    @instance_reservation_configs.setter
    def instance_reservation_configs(self, instance_reservation_configs):
        """
        Sets the instance_reservation_configs of this ComputeCapacityReservation.
        The reservation configurations for the capacity reservation.

        To use the reservation for the desired shape, specify the shape, count, and
        optionally the fault domain where you want this configuration.


        :param instance_reservation_configs: The instance_reservation_configs of this ComputeCapacityReservation.
        :type: list[oci.core.models.InstanceReservationConfig]
        """
        self._instance_reservation_configs = instance_reservation_configs

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ComputeCapacityReservation.
        The current state of the compute capacity reservation.

        Allowed values for this property are: "ACTIVE", "CREATING", "UPDATING", "MOVING", "DELETED", "DELETING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ComputeCapacityReservation.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ComputeCapacityReservation.
        The current state of the compute capacity reservation.


        :param lifecycle_state: The lifecycle_state of this ComputeCapacityReservation.
        :type: str
        """
        allowed_values = ["ACTIVE", "CREATING", "UPDATING", "MOVING", "DELETED", "DELETING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def reserved_instance_count(self):
        """
        Gets the reserved_instance_count of this ComputeCapacityReservation.
        The number of instances for which capacity will be held with this
        compute capacity reservation. This number is the sum of the values of the `reservedCount` fields
        for all of the instance reservation configurations under this reservation.
        The purpose of this field is to calculate the percentage usage of the reservation.


        :return: The reserved_instance_count of this ComputeCapacityReservation.
        :rtype: int
        """
        return self._reserved_instance_count

    @reserved_instance_count.setter
    def reserved_instance_count(self, reserved_instance_count):
        """
        Sets the reserved_instance_count of this ComputeCapacityReservation.
        The number of instances for which capacity will be held with this
        compute capacity reservation. This number is the sum of the values of the `reservedCount` fields
        for all of the instance reservation configurations under this reservation.
        The purpose of this field is to calculate the percentage usage of the reservation.


        :param reserved_instance_count: The reserved_instance_count of this ComputeCapacityReservation.
        :type: int
        """
        self._reserved_instance_count = reserved_instance_count

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ComputeCapacityReservation.
        The date and time the compute capacity reservation was updated, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this ComputeCapacityReservation.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ComputeCapacityReservation.
        The date and time the compute capacity reservation was updated, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this ComputeCapacityReservation.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ComputeCapacityReservation.
        The date and time the compute capacity reservation was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ComputeCapacityReservation.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ComputeCapacityReservation.
        The date and time the compute capacity reservation was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ComputeCapacityReservation.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def used_instance_count(self):
        """
        Gets the used_instance_count of this ComputeCapacityReservation.
        The total number of instances currently consuming space in
        this compute capacity reservation. This number is the sum of the values of the `usedCount` fields
        for all of the instance reservation configurations under this reservation.
        The purpose of this field is to calculate the percentage usage of the reservation.


        :return: The used_instance_count of this ComputeCapacityReservation.
        :rtype: int
        """
        return self._used_instance_count

    @used_instance_count.setter
    def used_instance_count(self, used_instance_count):
        """
        Sets the used_instance_count of this ComputeCapacityReservation.
        The total number of instances currently consuming space in
        this compute capacity reservation. This number is the sum of the values of the `usedCount` fields
        for all of the instance reservation configurations under this reservation.
        The purpose of this field is to calculate the percentage usage of the reservation.


        :param used_instance_count: The used_instance_count of this ComputeCapacityReservation.
        :type: int
        """
        self._used_instance_count = used_instance_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbSystemSnapshot(object):
    """
    Snapshot of the DbSystem details at the time of the backup
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DbSystemSnapshot object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DbSystemSnapshot.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this DbSystemSnapshot.
        :type display_name: str

        :param description:
            The value to assign to the description property of this DbSystemSnapshot.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DbSystemSnapshot.
        :type compartment_id: str

        :param subnet_id:
            The value to assign to the subnet_id property of this DbSystemSnapshot.
        :type subnet_id: str

        :param availability_domain:
            The value to assign to the availability_domain property of this DbSystemSnapshot.
        :type availability_domain: str

        :param fault_domain:
            The value to assign to the fault_domain property of this DbSystemSnapshot.
        :type fault_domain: str

        :param shape_name:
            The value to assign to the shape_name property of this DbSystemSnapshot.
        :type shape_name: str

        :param mysql_version:
            The value to assign to the mysql_version property of this DbSystemSnapshot.
        :type mysql_version: str

        :param admin_username:
            The value to assign to the admin_username property of this DbSystemSnapshot.
        :type admin_username: str

        :param backup_policy:
            The value to assign to the backup_policy property of this DbSystemSnapshot.
        :type backup_policy: oci.mysql.models.BackupPolicy

        :param configuration_id:
            The value to assign to the configuration_id property of this DbSystemSnapshot.
        :type configuration_id: str

        :param data_storage_size_in_gbs:
            The value to assign to the data_storage_size_in_gbs property of this DbSystemSnapshot.
        :type data_storage_size_in_gbs: int

        :param hostname_label:
            The value to assign to the hostname_label property of this DbSystemSnapshot.
        :type hostname_label: str

        :param ip_address:
            The value to assign to the ip_address property of this DbSystemSnapshot.
        :type ip_address: str

        :param port:
            The value to assign to the port property of this DbSystemSnapshot.
        :type port: int

        :param port_x:
            The value to assign to the port_x property of this DbSystemSnapshot.
        :type port_x: int

        :param is_highly_available:
            The value to assign to the is_highly_available property of this DbSystemSnapshot.
        :type is_highly_available: bool

        :param endpoints:
            The value to assign to the endpoints property of this DbSystemSnapshot.
        :type endpoints: list[oci.mysql.models.DbSystemEndpoint]

        :param maintenance:
            The value to assign to the maintenance property of this DbSystemSnapshot.
        :type maintenance: oci.mysql.models.MaintenanceDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DbSystemSnapshot.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DbSystemSnapshot.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'subnet_id': 'str',
            'availability_domain': 'str',
            'fault_domain': 'str',
            'shape_name': 'str',
            'mysql_version': 'str',
            'admin_username': 'str',
            'backup_policy': 'BackupPolicy',
            'configuration_id': 'str',
            'data_storage_size_in_gbs': 'int',
            'hostname_label': 'str',
            'ip_address': 'str',
            'port': 'int',
            'port_x': 'int',
            'is_highly_available': 'bool',
            'endpoints': 'list[DbSystemEndpoint]',
            'maintenance': 'MaintenanceDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'subnet_id': 'subnetId',
            'availability_domain': 'availabilityDomain',
            'fault_domain': 'faultDomain',
            'shape_name': 'shapeName',
            'mysql_version': 'mysqlVersion',
            'admin_username': 'adminUsername',
            'backup_policy': 'backupPolicy',
            'configuration_id': 'configurationId',
            'data_storage_size_in_gbs': 'dataStorageSizeInGBs',
            'hostname_label': 'hostnameLabel',
            'ip_address': 'ipAddress',
            'port': 'port',
            'port_x': 'portX',
            'is_highly_available': 'isHighlyAvailable',
            'endpoints': 'endpoints',
            'maintenance': 'maintenance',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._subnet_id = None
        self._availability_domain = None
        self._fault_domain = None
        self._shape_name = None
        self._mysql_version = None
        self._admin_username = None
        self._backup_policy = None
        self._configuration_id = None
        self._data_storage_size_in_gbs = None
        self._hostname_label = None
        self._ip_address = None
        self._port = None
        self._port_x = None
        self._is_highly_available = None
        self._endpoints = None
        self._maintenance = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DbSystemSnapshot.
        The OCID of the DB System.


        :return: The id of this DbSystemSnapshot.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DbSystemSnapshot.
        The OCID of the DB System.


        :param id: The id of this DbSystemSnapshot.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DbSystemSnapshot.
        The user-friendly name for the DB System. It does not have to be unique.


        :return: The display_name of this DbSystemSnapshot.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DbSystemSnapshot.
        The user-friendly name for the DB System. It does not have to be unique.


        :param display_name: The display_name of this DbSystemSnapshot.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this DbSystemSnapshot.
        User-provided data about the DB System.


        :return: The description of this DbSystemSnapshot.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DbSystemSnapshot.
        User-provided data about the DB System.


        :param description: The description of this DbSystemSnapshot.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DbSystemSnapshot.
        The OCID of the compartment the DB System belongs in.


        :return: The compartment_id of this DbSystemSnapshot.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DbSystemSnapshot.
        The OCID of the compartment the DB System belongs in.


        :param compartment_id: The compartment_id of this DbSystemSnapshot.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this DbSystemSnapshot.
        The OCID of the subnet the DB System is associated with.


        :return: The subnet_id of this DbSystemSnapshot.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this DbSystemSnapshot.
        The OCID of the subnet the DB System is associated with.


        :param subnet_id: The subnet_id of this DbSystemSnapshot.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this DbSystemSnapshot.
        The Availability Domain where the primary DB System should be located.


        :return: The availability_domain of this DbSystemSnapshot.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this DbSystemSnapshot.
        The Availability Domain where the primary DB System should be located.


        :param availability_domain: The availability_domain of this DbSystemSnapshot.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def fault_domain(self):
        """
        Gets the fault_domain of this DbSystemSnapshot.
        The name of the Fault Domain the DB System is located in.


        :return: The fault_domain of this DbSystemSnapshot.
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """
        Sets the fault_domain of this DbSystemSnapshot.
        The name of the Fault Domain the DB System is located in.


        :param fault_domain: The fault_domain of this DbSystemSnapshot.
        :type: str
        """
        self._fault_domain = fault_domain

    @property
    def shape_name(self):
        """
        Gets the shape_name of this DbSystemSnapshot.
        The shape of the primary instances of the DB System. The shape
        determines resources allocated to a DB System - CPU cores
        and memory for VM shapes; CPU cores, memory and storage for non-VM
        (or bare metal) shapes. To get a list of shapes, use (the
        :func:`list_shapes` operation.


        :return: The shape_name of this DbSystemSnapshot.
        :rtype: str
        """
        return self._shape_name

    @shape_name.setter
    def shape_name(self, shape_name):
        """
        Sets the shape_name of this DbSystemSnapshot.
        The shape of the primary instances of the DB System. The shape
        determines resources allocated to a DB System - CPU cores
        and memory for VM shapes; CPU cores, memory and storage for non-VM
        (or bare metal) shapes. To get a list of shapes, use (the
        :func:`list_shapes` operation.


        :param shape_name: The shape_name of this DbSystemSnapshot.
        :type: str
        """
        self._shape_name = shape_name

    @property
    def mysql_version(self):
        """
        **[Required]** Gets the mysql_version of this DbSystemSnapshot.
        Name of the MySQL Version in use for the DB System.


        :return: The mysql_version of this DbSystemSnapshot.
        :rtype: str
        """
        return self._mysql_version

    @mysql_version.setter
    def mysql_version(self, mysql_version):
        """
        Sets the mysql_version of this DbSystemSnapshot.
        Name of the MySQL Version in use for the DB System.


        :param mysql_version: The mysql_version of this DbSystemSnapshot.
        :type: str
        """
        self._mysql_version = mysql_version

    @property
    def admin_username(self):
        """
        Gets the admin_username of this DbSystemSnapshot.
        The username for the administrative user.


        :return: The admin_username of this DbSystemSnapshot.
        :rtype: str
        """
        return self._admin_username

    @admin_username.setter
    def admin_username(self, admin_username):
        """
        Sets the admin_username of this DbSystemSnapshot.
        The username for the administrative user.


        :param admin_username: The admin_username of this DbSystemSnapshot.
        :type: str
        """
        self._admin_username = admin_username

    @property
    def backup_policy(self):
        """
        Gets the backup_policy of this DbSystemSnapshot.

        :return: The backup_policy of this DbSystemSnapshot.
        :rtype: oci.mysql.models.BackupPolicy
        """
        return self._backup_policy

    @backup_policy.setter
    def backup_policy(self, backup_policy):
        """
        Sets the backup_policy of this DbSystemSnapshot.

        :param backup_policy: The backup_policy of this DbSystemSnapshot.
        :type: oci.mysql.models.BackupPolicy
        """
        self._backup_policy = backup_policy

    @property
    def configuration_id(self):
        """
        Gets the configuration_id of this DbSystemSnapshot.
        The OCID of the Configuration to be used for Instances in this DB System.


        :return: The configuration_id of this DbSystemSnapshot.
        :rtype: str
        """
        return self._configuration_id

    @configuration_id.setter
    def configuration_id(self, configuration_id):
        """
        Sets the configuration_id of this DbSystemSnapshot.
        The OCID of the Configuration to be used for Instances in this DB System.


        :param configuration_id: The configuration_id of this DbSystemSnapshot.
        :type: str
        """
        self._configuration_id = configuration_id

    @property
    def data_storage_size_in_gbs(self):
        """
        **[Required]** Gets the data_storage_size_in_gbs of this DbSystemSnapshot.
        Initial size of the data volume in GiBs that will be created and attached.


        :return: The data_storage_size_in_gbs of this DbSystemSnapshot.
        :rtype: int
        """
        return self._data_storage_size_in_gbs

    @data_storage_size_in_gbs.setter
    def data_storage_size_in_gbs(self, data_storage_size_in_gbs):
        """
        Sets the data_storage_size_in_gbs of this DbSystemSnapshot.
        Initial size of the data volume in GiBs that will be created and attached.


        :param data_storage_size_in_gbs: The data_storage_size_in_gbs of this DbSystemSnapshot.
        :type: int
        """
        self._data_storage_size_in_gbs = data_storage_size_in_gbs

    @property
    def hostname_label(self):
        """
        Gets the hostname_label of this DbSystemSnapshot.
        The hostname for the primary endpoint of the DB System. Used for DNS.
        The value is the hostname portion of the primary private IP's fully qualified domain name (FQDN)
        (for example, \"dbsystem-1\" in FQDN \"dbsystem-1.subnet123.vcn1.oraclevcn.com\").
        Must be unique across all VNICs in the subnet and comply with RFC 952 and RFC 1123.


        :return: The hostname_label of this DbSystemSnapshot.
        :rtype: str
        """
        return self._hostname_label

    @hostname_label.setter
    def hostname_label(self, hostname_label):
        """
        Sets the hostname_label of this DbSystemSnapshot.
        The hostname for the primary endpoint of the DB System. Used for DNS.
        The value is the hostname portion of the primary private IP's fully qualified domain name (FQDN)
        (for example, \"dbsystem-1\" in FQDN \"dbsystem-1.subnet123.vcn1.oraclevcn.com\").
        Must be unique across all VNICs in the subnet and comply with RFC 952 and RFC 1123.


        :param hostname_label: The hostname_label of this DbSystemSnapshot.
        :type: str
        """
        self._hostname_label = hostname_label

    @property
    def ip_address(self):
        """
        Gets the ip_address of this DbSystemSnapshot.
        The IP address the DB System is configured to listen on. A private
        IP address of the primary endpoint of the DB System. Must be an
        available IP address within the subnet's CIDR. This will be a
        \"dotted-quad\" style IPv4 address.


        :return: The ip_address of this DbSystemSnapshot.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this DbSystemSnapshot.
        The IP address the DB System is configured to listen on. A private
        IP address of the primary endpoint of the DB System. Must be an
        available IP address within the subnet's CIDR. This will be a
        \"dotted-quad\" style IPv4 address.


        :param ip_address: The ip_address of this DbSystemSnapshot.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def port(self):
        """
        Gets the port of this DbSystemSnapshot.
        The port for primary endpoint of the DB System to listen on.


        :return: The port of this DbSystemSnapshot.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this DbSystemSnapshot.
        The port for primary endpoint of the DB System to listen on.


        :param port: The port of this DbSystemSnapshot.
        :type: int
        """
        self._port = port

    @property
    def port_x(self):
        """
        Gets the port_x of this DbSystemSnapshot.
        The network port on which X Plugin listens for TCP/IP connections. This is the X Plugin equivalent of port.


        :return: The port_x of this DbSystemSnapshot.
        :rtype: int
        """
        return self._port_x

    @port_x.setter
    def port_x(self, port_x):
        """
        Sets the port_x of this DbSystemSnapshot.
        The network port on which X Plugin listens for TCP/IP connections. This is the X Plugin equivalent of port.


        :param port_x: The port_x of this DbSystemSnapshot.
        :type: int
        """
        self._port_x = port_x

    @property
    def is_highly_available(self):
        """
        Gets the is_highly_available of this DbSystemSnapshot.
        If the policy is to enable high availability of the instance, by
        maintaining secondary/failover capacity as necessary.


        :return: The is_highly_available of this DbSystemSnapshot.
        :rtype: bool
        """
        return self._is_highly_available

    @is_highly_available.setter
    def is_highly_available(self, is_highly_available):
        """
        Sets the is_highly_available of this DbSystemSnapshot.
        If the policy is to enable high availability of the instance, by
        maintaining secondary/failover capacity as necessary.


        :param is_highly_available: The is_highly_available of this DbSystemSnapshot.
        :type: bool
        """
        self._is_highly_available = is_highly_available

    @property
    def endpoints(self):
        """
        Gets the endpoints of this DbSystemSnapshot.
        The network endpoints available for this DB System.


        :return: The endpoints of this DbSystemSnapshot.
        :rtype: list[oci.mysql.models.DbSystemEndpoint]
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """
        Sets the endpoints of this DbSystemSnapshot.
        The network endpoints available for this DB System.


        :param endpoints: The endpoints of this DbSystemSnapshot.
        :type: list[oci.mysql.models.DbSystemEndpoint]
        """
        self._endpoints = endpoints

    @property
    def maintenance(self):
        """
        **[Required]** Gets the maintenance of this DbSystemSnapshot.

        :return: The maintenance of this DbSystemSnapshot.
        :rtype: oci.mysql.models.MaintenanceDetails
        """
        return self._maintenance

    @maintenance.setter
    def maintenance(self, maintenance):
        """
        Sets the maintenance of this DbSystemSnapshot.

        :param maintenance: The maintenance of this DbSystemSnapshot.
        :type: oci.mysql.models.MaintenanceDetails
        """
        self._maintenance = maintenance

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DbSystemSnapshot.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DbSystemSnapshot.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DbSystemSnapshot.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DbSystemSnapshot.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DbSystemSnapshot.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DbSystemSnapshot.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DbSystemSnapshot.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DbSystemSnapshot.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
